Citation
--------

If you use MolDrug in your research, please cite the DOI corresponding to the release version you've used:

.. list-table:: MolDrug releases
    :widths: 10 10 15
    :align: center

    * - Version
      - Release date
      - DOI
    * - Any
      - 2022-07-10
      - ..  image:: https://zenodo.org/badge/496163299.svg
            :target: https://zenodo.org/badge/latestdoi/496163299